@@ -6,19 +6,29 @@ from django.conf import settings
 from django.utils.functional import SimpleLazyObject, cached_property
 from django.utils.module_loading import import_string
 from django_regex.utils import RegexList
-from front_door.utils import parse_bool
+from front_door.utils import parse_bool, parse_policy
 
 FRONT_DOOR_CONFIG = getattr(settings, "FRONT_DOOR_CONFIG", "front_door.conf.DjangoSettings")
 
 logger = logging.getLogger(__name__)
 
+FORBID = False
+ALLOW = True
+
 
 class FrontDoorConfig:
     defaults = dict(
-        ALLOWED_PATHS=[],  # url paths regex list always allowed
-        ENABLED=False,  # FrontDoor enable/disable
-        FORBIDDEN_PATHS=[],  # url paths regex list always denied
         ALLOWED_IPS=[],  # allowed ips
+        ALLOWED_PATHS=[],  # url paths regex list always allowed
+        COOKIE_NAME=None,
+        COOKIE_PATTERN=None,
+        DEFAULT_POLICY=FORBID,
+        ENABLED=False,  # FrontDoor enable/disable
+        ERROR_CODE=404,
+        FORBIDDEN_PATHS=[],  # url paths regex list always denied
+        HEADER=None,  # special header name without HTTP- prefix
+        REDIR_URL="",
+        ROUTER="front_door.router.DefaultRouter",
         RULES=[
             "front_door.rules.forbidden_path",
             "front_door.rules.allowed_ip",
@@ -27,13 +37,7 @@ class FrontDoorConfig:
             "front_door.rules.special_header",
             "front_door.rules.cookie_value",
         ],
-        ROUTER="front_door.router.DefaultRouter",
-        HEADER=None,  # special header name without HTTP- prefix
         TOKEN=None,  # custom header value
-        REDIR_URL="",
-        ERROR_CODE=404,
-        COOKIE_NAME=None,
-        COOKIE_PATTERN=None,
     )
 
     def __init__(self) -> None:
@@ -58,6 +62,10 @@ class FrontDoorConfig:
             return self._get(key)
         raise AttributeError(key)
 
+    @cached_property
+    def DEFAULT_POLICY(self):
+        return parse_policy(self._get("DEFAULT_POLICY"))
+
     @cached_property
     def COOKIE_PATTERN(self):
         try:
